<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * @category    SuperMailingList/SuperWebMailer
 * @package     sml_swm
 * @author      Mirko Boeer <info@supermailer.de>
 * @copyright   2018 Mirko Boeer
 * @license     http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */
class sml_swm_Model_Observer
{

    // from Mage_Newsletter_Model_Subscriber
    const STATUS_SUBSCRIBED     = 1;
    const STATUS_NOT_ACTIVE     = 2;
    const STATUS_UNSUBSCRIBED   = 3;
    const STATUS_UNCONFIRMED    = 4;

    public function customerSave(Varien_Event_Observer $observer)
    {
        try {
            if (Mage::app()->getRequest()->getActionName() == 'saveOrder') return;

            $old_data = $observer->getCustomer()->getOrigData();
            $new_data = $observer->getCustomer()->getData();

            if (isset($old_data['email']) && isset($new_data['email']) && isset($old_data['store_id']) && isset($new_data['store_id']) && isset($old_data['website_id']) &&
                isset($new_data['website_id']) && $old_data['website_id'] && $new_data['website_id']) {

                $config = Mage::helper('swm')->getConfiguration();
                if(!$config["complete"]) return;

                $old_email = $old_data['email'];
                $new_email = $new_data['email'];
                $old_store_id = $old_data['store_id'];
                $new_store_id = $new_data['store_id'];

                if ($old_email != $new_email || $old_store_id != $new_store_id) {

                   if($old_store_id != $new_store_id){
                     $result_old = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $old_store_id);
                     $result_new = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $new_store_id);
                     for($i=0; $i<count($result_old); $i++)
                       Mage::helper('swm')->removeRecipientFromMailingList($config, $result_old[$i], $old_email);
                     for($i=0; $i<count($result_new); $i++)
                       Mage::helper('swm')->removeRecipientFromMailingList($config, $result_new[$i], $new_email);
                   }else{
                     $result_old = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $old_store_id);
                     for($i=0; $i<count($result_old); $i++)
                       Mage::helper('swm')->editRecipientInMailingList($config, $result_old[$i], $old_email, $new_email);
                   }

                }
            }
        }
        catch(Exception $e) {}
    }

    public function customerDelete(Varien_Event_Observer $observer)
    {
        try {
            $data = $observer->getCustomer()->getData();
            if (isset($data['email']) && isset($data['entity_id']) && isset($data['store_id']) && isset($data['website_id'])) {
              $config = Mage::helper('swm')->getConfiguration();
              if(!$config["complete"]) return;
              $result = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $data['store_id']);
              for($i=0; $i<count($result); $i++)
                Mage::helper('swm')->removeRecipientFromMailingList($config, $result[$i], $data['email']);
            }
        }
        catch(Exception $e) {}
    }

    public function newsletterSubscriberSave(Varien_Event_Observer $observer)
    {
        try {
            if (Mage::app()->getRequest()->getActionName() == 'saveOrder') return;
            $action_name = Mage::app()->getRequest()->getActionName();
            $data = $observer->getSubscriber()->getData();

            if (isset($data['subscriber_email']) && isset($data['store_id']) && isset($data['subscriber_status'])) {

                //Mage::helper('swm')->sendDebugEMail($action_name, $data);

                $config = Mage::helper('swm')->getConfiguration();
                if(!$config["complete"]) return;
                $result = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $data['store_id']);

                if($data['subscriber_status'] == self::STATUS_SUBSCRIBED){
                  for($i=0; $i<count($result); $i++)
                    Mage::helper('swm')->addRecipientToMailingList($config, $result[$i], $data['subscriber_email']);
                }

                if($data['subscriber_status'] == self::STATUS_UNSUBSCRIBED){
                  for($i=0; $i<count($result); $i++)
                    Mage::helper('swm')->removeRecipientFromMailingList($config, $result[$i], $data['subscriber_email']);
                }

                if($data['subscriber_status'] == self::STATUS_NOT_ACTIVE && empty($data['subscriber_confirm_code'])){
                  for($i=0; $i<count($result); $i++)
                    Mage::helper('swm')->removeRecipientFromMailingList($config, $result[$i], $data['subscriber_email']);
                }

                if($data['subscriber_status'] == self::STATUS_UNCONFIRMED){
                 // we do nothing
                }

            }
        }
        catch(Exception $e) {}
    }

    public function newsletterSubscriberDelete(Varien_Event_Observer $observer)
    {
        try {

            $data = $observer->getSubscriber()->getData();

            if (isset($data['subscriber_email']) && isset($data['store_id']) && isset($data['subscriber_status'])) {

                $config = Mage::helper('swm')->getConfiguration();
                if(!$config["complete"]) return;
                $result = Mage::helper('swm')->getswmlswm_mailinglistIdsFromStoreID($config, $data['store_id']);

                if($data['subscriber_status'] != self::STATUS_UNCONFIRMED)
                  for($i=0; $i<count($result); $i++)
                     Mage::helper('swm')->removeRecipientFromMailingList($config, $result[$i], $data['subscriber_email']);

            }
        }
        catch(Exception $e) {}
    }

}
?>